@@ -5,34 +5,17 @@ use super::{
 };
 use crate::{
     components::{CommandInfo, Component},
-    keys,
+    keys::SharedKeyConfig,
     queue::{Action, InternalEvent, NeedsUpdate, Queue, ResetItem},
-    strings,
+    strings, try_or_popup,
     ui::style::SharedTheme,
 };
 use anyhow::Result;
 use asyncgit::{cached, sync, StatusItem, StatusItemType, CWD};
 use crossterm::event::Event;
 use std::path::Path;
-use strings::commands;
 use tui::{backend::Backend, layout::Rect, Frame};
 
-/// macro to simplify running code that might return Err.
-/// It will show a popup in that case
-#[macro_export]
-macro_rules! try_or_popup {
-    ($self:ident, $msg:literal, $e:expr) => {
-        if let Err(err) = $e {
-            $self.queue.borrow_mut().push_back(
-                InternalEvent::ShowErrorMsg(format!(
-                    "{}\n{}",
-                    $msg, err
-                )),
-            );
-        }
-    };
-}
-
 ///
 pub struct ChangesComponent {
     title: String,
@@ -40,6 +23,7 @@ pub struct ChangesComponent {
     is_working_dir: bool,
     queue: Queue,
     branch_name: cached::BranchName,
+    key_config: SharedKeyConfig,
 }
 
 impl ChangesComponent {
@@ -50,6 +34,7 @@ impl ChangesComponent {
         is_working_dir: bool,
         queue: Queue,
         theme: SharedTheme,
+        key_config: SharedKeyConfig,
     ) -> Self {
         Self {
             title: title.into(),
@@ -58,10 +43,12 @@ impl ChangesComponent {
                 focus,
                 Some(queue.clone()),
                 theme,
+                key_config.clone(),
             ),
             is_working_dir,
             queue,
             branch_name: cached::BranchName::new(CWD),
+            key_config,
         }
     }
 
@@ -222,39 +209,39 @@ impl Component for ChangesComponent {
 
         if self.is_working_dir {
             out.push(CommandInfo::new(
-                commands::STAGE_ALL,
+                strings::commands::stage_all(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
             out.push(CommandInfo::new(
-                commands::STAGE_ITEM,
+                strings::commands::stage_item(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
             out.push(CommandInfo::new(
-                commands::RESET_ITEM,
+                strings::commands::reset_item(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
             out.push(CommandInfo::new(
-                commands::IGNORE_ITEM,
+                strings::commands::ignore_item(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
         } else {
             out.push(CommandInfo::new(
-                commands::UNSTAGE_ITEM,
+                strings::commands::unstage_item(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
             out.push(CommandInfo::new(
-                commands::UNSTAGE_ALL,
+                strings::commands::unstage_all(&self.key_config),
                 some_selection,
                 self.focused(),
             ));
             out.push(
                 CommandInfo::new(
-                    commands::COMMIT_OPEN,
+                    strings::commands::commit_open(&self.key_config),
                     !self.is_empty(),
                     self.focused() || force_all,
                 )
@@ -272,57 +259,49 @@ impl Component for ChangesComponent {
 
         if self.focused() {
             if let Event::Key(e) = ev {
-                return match e {
-                    keys::OPEN_COMMIT
-                        if !self.is_working_dir
-                            && !self.is_empty() =>
-                    {
-                        self.queue
-                            .borrow_mut()
-                            .push_back(InternalEvent::OpenCommit);
-                        Ok(true)
-                    }
-                    keys::STATUS_STAGE_FILE => {
+                return if e == self.key_config.open_commit
+                    && !self.is_working_dir
+                    && !self.is_empty()
+                {
+                    self.queue
+                        .borrow_mut()
+                        .push_back(InternalEvent::OpenCommit);
+                    Ok(true)
+                } else if e == self.key_config.enter {
+                    try_or_popup!(
+                        self,
+                        "staging error:",
+                        self.index_add_remove()
+                    );
+
+                    self.queue.borrow_mut().push_back(
+                        InternalEvent::Update(NeedsUpdate::ALL),
+                    );
+                    Ok(true)
+                } else if e == self.key_config.status_stage_all
+                    && !self.is_empty()
+                {
+                    if self.is_working_dir {
                         try_or_popup!(
                             self,
                             "staging error:",
-                            self.index_add_remove()
+                            self.index_add_all()
                         );
-
-                        self.queue.borrow_mut().push_back(
-                            InternalEvent::Update(NeedsUpdate::ALL),
-                        );
-
-                        Ok(true)
+                    } else {
+                        self.stage_remove_all()?;
                     }
-
-                    keys::STATUS_STAGE_ALL if !self.is_empty() => {
-                        if self.is_working_dir {
-                            try_or_popup!(
-                                self,
-                                "staging error:",
-                                self.index_add_all()
-                            );
-                        } else {
-                            self.stage_remove_all()?;
-                        }
-
-                        Ok(true)
-                    }
-
-                    keys::STATUS_RESET_FILE
-                        if self.is_working_dir =>
-                    {
-                        Ok(self.dispatch_reset_workdir())
-                    }
-
-                    keys::STATUS_IGNORE_FILE
-                        if self.is_working_dir
-                            && !self.is_empty() =>
-                    {
-                        Ok(self.add_to_ignore())
-                    }
-                    _ => Ok(false),
+                    Ok(true)
+                } else if e == self.key_config.status_reset_item
+                    && self.is_working_dir
+                {
+                    Ok(self.dispatch_reset_workdir())
+                } else if e == self.key_config.status_ignore_file
+                    && self.is_working_dir
+                    && !self.is_empty()
+                {
+                    Ok(self.add_to_ignore())
+                } else {
+                    Ok(false)
                 };
             }
         }
