@@ -8,9 +8,9 @@ use crate::{
     strings, try_or_popup,
     ui::{self, calc_scroll_top, style::SharedTheme},
 };
+use anyhow::Result;
 use asyncgit::{hash, sync, DiffLine, DiffLineType, FileDiff, CWD};
 use bytesize::ByteSize;
-use clipboard::{ClipboardContext, ClipboardProvider};
 use crossterm::event::Event;
 use std::{borrow::Cow, cell::Cell, cmp, path::Path};
 use tui::{
@@ -21,8 +21,6 @@ use tui::{
     Frame,
 };
 
-use anyhow::{anyhow, Result};
-
 #[derive(Default)]
 struct Current {
     path: String,
@@ -244,18 +242,6 @@ impl DiffComponent {
         Ok(())
     }
 
-    fn copy_string(string: String) -> Result<()> {
-        let mut ctx: ClipboardContext = ClipboardProvider::new()
-            .map_err(|_| {
-                anyhow!("failed to get access to clipboard")
-            })?;
-        ctx.set_contents(string).map_err(|_| {
-            anyhow!("failed to set clipboard contents")
-        })?;
-
-        Ok(())
-    }
-
     fn copy_selection(&self) -> Result<()> {
         if let Some(diff) = &self.diff {
             let lines_to_copy: Vec<&str> = diff
@@ -281,7 +267,9 @@ impl DiffComponent {
             try_or_popup!(
                 self,
                 "copy to clipboard error:",
-                Self::copy_string(lines_to_copy.join("\n"))
+                crate::clipboard::copy_string(
+                    lines_to_copy.join("\n")
+                )
             );
         }
 
@@ -616,11 +604,13 @@ impl Component for DiffComponent {
             self.focused,
         ));
 
-        out.push(CommandInfo::new(
-            strings::commands::copy(&self.key_config),
-            true,
-            self.focused,
-        ));
+        if crate::clipboard::is_supported() {
+            out.push(CommandInfo::new(
+                strings::commands::copy(&self.key_config),
+                true,
+                self.focused,
+            ));
+        }
 
         out.push(
             CommandInfo::new(
@@ -700,7 +690,9 @@ impl Component for DiffComponent {
                         }
                     }
                     Ok(true)
-                } else if e == self.key_config.copy {
+                } else if e == self.key_config.copy
+                    && crate::clipboard::is_supported()
+                {
                     self.copy_selection()?;
                     Ok(true)
                 } else {
